"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildTokenId = exports.isNativeCosmWasmDenom = exports.isNativeDenomProvenance = exports.isNativeDenomDymension = exports.isNativeDenomSeda = exports.isNativeDenomStargaze = exports.isNativeDenomCelestia = exports.isNativeDenomNeutron = exports.isNativeDenomKujira = exports.isNativeDenomEvmos = exports.isNativeDenomCosmosHub = exports.isNativeDenomOsmosis = exports.isNativeDenomWormchain = exports.isNativeDenomSei = exports.isNativeDenomXpla = exports.isNativeDenomInjective = void 0;
const js_sha3_1 = require("js-sha3");
const utils_1 = require("../utils");
const isNativeDenomInjective = (denom) => denom === "inj";
exports.isNativeDenomInjective = isNativeDenomInjective;
const isNativeDenomXpla = (denom) => denom === "axpla";
exports.isNativeDenomXpla = isNativeDenomXpla;
const isNativeDenomSei = (denom) => denom === "usei";
exports.isNativeDenomSei = isNativeDenomSei;
const isNativeDenomWormchain = (denom) => denom === "uworm";
exports.isNativeDenomWormchain = isNativeDenomWormchain;
const isNativeDenomOsmosis = (denom) => denom === "uosmo";
exports.isNativeDenomOsmosis = isNativeDenomOsmosis;
const isNativeDenomCosmosHub = (denom) => denom === "uatom";
exports.isNativeDenomCosmosHub = isNativeDenomCosmosHub;
const isNativeDenomEvmos = (denom) => denom === "aevmos" || denom === "atevmos";
exports.isNativeDenomEvmos = isNativeDenomEvmos;
const isNativeDenomKujira = (denom) => denom === "ukuji";
exports.isNativeDenomKujira = isNativeDenomKujira;
const isNativeDenomNeutron = (denom) => denom === "untrn";
exports.isNativeDenomNeutron = isNativeDenomNeutron;
const isNativeDenomCelestia = (denom) => denom === "utia";
exports.isNativeDenomCelestia = isNativeDenomCelestia;
const isNativeDenomStargaze = (denom) => denom === "ustars";
exports.isNativeDenomStargaze = isNativeDenomStargaze;
const isNativeDenomSeda = (denom) => denom === "aseda";
exports.isNativeDenomSeda = isNativeDenomSeda;
const isNativeDenomDymension = (denom) => denom === "adym";
exports.isNativeDenomDymension = isNativeDenomDymension;
const isNativeDenomProvenance = (denom) => denom === "nhash";
exports.isNativeDenomProvenance = isNativeDenomProvenance;
function isNativeCosmWasmDenom(chainId, address) {
    return ((chainId === utils_1.CHAIN_ID_INJECTIVE && exports.isNativeDenomInjective(address)) ||
        (chainId === utils_1.CHAIN_ID_XPLA && exports.isNativeDenomXpla(address)) ||
        (chainId === utils_1.CHAIN_ID_SEI && exports.isNativeDenomSei(address)) ||
        (chainId === utils_1.CHAIN_ID_WORMCHAIN && exports.isNativeDenomWormchain(address)) ||
        (chainId === utils_1.CHAIN_ID_OSMOSIS && exports.isNativeDenomOsmosis(address)) ||
        (chainId === utils_1.CHAIN_ID_COSMOSHUB && exports.isNativeDenomCosmosHub(address)) ||
        (chainId === utils_1.CHAIN_ID_EVMOS && exports.isNativeDenomEvmos(address)) ||
        (chainId === utils_1.CHAIN_ID_KUJIRA && exports.isNativeDenomKujira(address)) ||
        (chainId === utils_1.CHAIN_ID_NEUTRON && exports.isNativeDenomNeutron(address)) ||
        (chainId === utils_1.CHAIN_ID_CELESTIA && exports.isNativeDenomCelestia(address)) ||
        (chainId === utils_1.CHAIN_ID_STARGAZE && exports.isNativeDenomStargaze(address)) ||
        (chainId === utils_1.CHAIN_ID_SEDA && exports.isNativeDenomSeda(address)) ||
        (chainId === utils_1.CHAIN_ID_DYMENSION && exports.isNativeDenomDymension(address)) ||
        (chainId === utils_1.CHAIN_ID_PROVENANCE && exports.isNativeDenomProvenance(address)));
}
exports.isNativeCosmWasmDenom = isNativeCosmWasmDenom;
function buildTokenId(chain, address) {
    const chainId = utils_1.coalesceCosmWasmChainId(chain);
    return ((isNativeCosmWasmDenom(chainId, address) ? "01" : "00") +
        js_sha3_1.keccak256(Buffer.from(address, "utf-8")).substring(4));
}
exports.buildTokenId = buildTokenId;
